@@ -236,7 +236,7 @@ handle_dbus_events(DBusConnection *connection, DBusMessage *msg, void *user_data
 }
 
 
-
+#ifdef SHOW_PROCESS_INFO
 /*
  * Show the details dialog (FAKE)
  *
@@ -273,7 +273,7 @@ activate_status_item(GtkMenuItem *item, gpointer data)
 	gtk_widget_show_all(GTK_WIDGET(dialog));
 	//gtk_dialog_run(GTK_DIALOG(dialog)); <- blocks and won't close status menu
 }
-
+#endif
 
 
 
@@ -283,6 +283,9 @@ activate_status_item(GtkMenuItem *item, gpointer data)
 static void
 activate_delayed_screenshot_item(GtkMenuItem *item, gpointer data)
 {
+	if (taking)
+		return;
+	
 	LoadAppletStatusMenuItem *menu_item = (LoadAppletStatusMenuItem*)data;
 	menu_item->priv = LOAD_APPLET_STATUS_MENU_ITEM_GET_PRIVATE (menu_item);
 
@@ -330,7 +333,7 @@ activate_video_item(GtkMenuItem *item, gpointer data)
 		savefile = g_strdup_printf("location=%s", sshotname);
 		rec_pid = fork();
 		if (rec_pid == 0) {
-			execl("/usr/bin/gst-launch", "/usr/bin/gst-launch", "ximagesrc", "!", "video/x-raw-rgb,framerate=5/1", "!", "ffmpegcolorspace", "!", "jpegenc", "quality=50", "!", "queue", "!", "mux.", "autoaudiosrc", "!", "audioconvert", "!", "audioresample", "!", "queue", "!", "mux.", "avimux", "name=mux", "!", "filesink", savefile, NULL); 
+			execl("/usr/bin/gst-launch", "/usr/bin/gst-launch", "ximagewsrc", "!", "video/x-raw-rgb,framerate=5/1", "!", "ffmpegcolorspace", "!", "jpegenc", "quality=30", "!", "queue", "!", "mux.", "autoaudiosrc", "!", "audioconvert", "!", "audioresample", "!", "queue", "!", "mux.", "avimux", "name=mux", "!", "filesink", savefile, NULL); 
 			exit(0);
 		} else {
 			la_item->priv->recording = TRUE;
@@ -362,6 +365,7 @@ load_applet_status_menu_item_init (LoadAppletStatusMenuItem * menu_item)
 
 	sshotfilename = g_strdup("screenshot");
 
+#ifdef SHOW_PROCESS_INFO
 	// Button status
 	b = hildon_button_new(HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL); 
 	hildon_button_set_style(HILDON_BUTTON(b), HILDON_BUTTON_STYLE_PICKER);
@@ -371,6 +375,7 @@ load_applet_status_menu_item_init (LoadAppletStatusMenuItem * menu_item)
 	gtk_button_set_image(GTK_BUTTON(b), GTK_WIDGET(icon));
 	gtk_box_pack_start(GTK_BOX(hbox), b, TRUE, TRUE, 1);
 	g_signal_connect(b, "clicked", G_CALLBACK(activate_status_item), menu_item);
+#endif
 	// Button Video
 	b = gtk_toggle_button_new();
 	gtk_widget_show(b);
